
local iLocalPlayer = Game:GetLocalPlayer();
local iBarbCamp = GameInfo.Improvements["IMPROVEMENT_BARBARIAN_CAMP"].Index;
local iCityPopChangedNotificationHash = NotificationTypes.USER_DEFINED_9;
local iCityTileOwnershipChangedNotificationHash = NotificationTypes.USER_DEFINED_8;
-- local iBarbCampSpottedNotificationHash = NotificationTypes.USER_DEFINED_7;
local iDealExpiredNotificationHash = NotificationTypes.USER_DEFINED_7;


local function OnCityPopulationChanged( iPlayerID, iCityID, iChangeAmount )
	-- bug:  fires with iChangeAmount == 0 when unit is built 
	if iPlayerID == iLocalPlayer then
		if iChangeAmount > 0 then 
			local pCity = CityManager.GetCity(iPlayerID, iCityID);
			local sCityName = Locale.Lookup(pCity:GetName());
			print("OnCityPopulationChanged: "..sCityName, iChangeAmount);
			NotificationManager.SendNotification(iPlayerID, iCityPopChangedNotificationHash, "Population  of  "..sCityName.."  grows", '', pCity:GetX(), pCity:GetY());
		-- elseif iChangeAmount < 0 then
			-- local pCity = CityManager.GetCity(iPlayerID, iCityID); -- GetJustConqueredFrom
			-- local sCityName = Locale.Lookup(pCity:GetName());
			-- print("OnCityPopulationChanged: "..sCityName, iChangeAmount);
			-- NotificationManager.SendNotification(iPlayerID, iCityPopChangedNotificationHash, "Population  of  "..sCityName.."  decreases", '', pCity:GetX(), pCity:GetY());
		end
	end
end


local function OnCityTileOwnershipChanged( iPlayerID: number, iCityID : number )

	if iPlayerID == iLocalPlayer then
		local pCity = CityManager.GetCity(iPlayerID, iCityID);
		local sCityName = Locale.Lookup(pCity:GetName());
		print("OnCityTileOwnershipChanged: "..sCityName);
		NotificationManager.SendNotification(iPlayerID, iCityTileOwnershipChangedNotificationHash, "City  of  "..sCityName.."  expands  its  borders", '', pCity:GetX(), pCity:GetY());
	end
end


local function OnImprovementAddedToMap(iX, iY, improvementType, iImprovementOwner, resource, isPillaged, isWorked)
	if improvementType == iBarbCamp then
		local pLocalPlayerVis = PlayerVisibilityManager.GetPlayerVisibility(iLocalPlayer);

		if pLocalPlayerVis ~= nil and pLocalPlayerVis:IsRevealed(Map.GetPlot(iX,iY)) then
			-- print("Barb camp added to map.");
			NotificationManager.SendNotification(iPlayerID, iBarbCampSpottedNotificationHash, 'Barbarian  camp  spotted','', iX, iY);
		end
	end
end


local function OnLocalPlayerTurnEnd()

	-- print("OnLocalPlayerTurnEnd");
	Events.CityTileOwnershipChanged.Add( OnCityTileOwnershipChanged );
	GameEvents.OnCityPopulationChanged.Add( OnCityPopulationChanged ); 
end


local function OnPlayerTurnActivated ( iPlayerID, someBoolean)

	if iPlayerID == iLocalPlayer then
		-- print("OnPlayerTurnActivated");

		-- CityTileOwnershipChanged fires when player founds city so dont listen when turn is active
		Events.CityTileOwnershipChanged.Remove( OnCityTileOwnershipChanged );

		-- CityPopulationChanged fires when player founds or conquers a city so dont listen when turn is active
		GameEvents.OnCityPopulationChanged.Remove( OnCityPopulationChanged ); 
	end
end


local function OnDiplomacyDealExpired (iPlayer1, iPlayer2)

	if iPlayer1 == iLocalPlayer then
		print("OnDiplomacyDealExpired");
		local sPlayer2name = Locale.Lookup(PlayerConfigurations[iPlayer2]:GetLeaderName());
		NotificationManager.SendNotification(iLocalPlayer, iDealExpiredNotificationHash, 'Your trade deal with '..sPlayer2name..' has expired.','', nil, nil);
	elseif iPlayer2 == iLocalPlayer then
		print("OnDiplomacyDealExpired");
		local sPlayer2name = Locale.Lookup(PlayerConfigurations[iPlayer1]:GetLeaderName());
		NotificationManager.SendNotification(iLocalPlayer, iDealExpiredNotificationHash, 'Your trade deal with '..sPlayer2name..' has expired.','', nil, nil);
	end
end


local function Initialize() 
	Events.DiplomacyDealExpired.Add(OnDiplomacyDealExpired);
	-- Events.ImprovementAddedToMap.Add( OnImprovementAddedToMap );
	Events.LocalPlayerTurnEnd.Add( OnLocalPlayerTurnEnd );
	Events.PlayerTurnActivated.Add( OnPlayerTurnActivated ); 
	-- GameEvents.OnCityPopulationChanged.Add( OnCityPopulationChanged ); 
	print("CUSTOM NOTIFICATIONS STARTED.");
end
Events.LoadScreenClose.Add(Initialize);
